@@ -63,17 +63,17 @@ int main(int argc, char *argv[])
      
   MyWindow myWindow;
   try
-	{
-		curlpp::Cleanup cleaner;
-		curlpp::Easy request;
-    
-		using namespace curlpp::Options;
-    request.setOpt(Verbose(true));
-		request.setOpt(DebugFunction(curlpp::types::DebugFunctionFunctor(&myWindow, 
-								     &MyWindow::writeDebug)));
-    request.setOpt(Url(url));
-    
-    request.perform();
+  {
+      curlpp::Cleanup cleaner;
+      curlpp::Easy request;
+      
+      using namespace curlpp::Options;
+      request.setOpt(Verbose(true));
+      using namespace std::placeholders;
+      request.setOpt(DebugFunction(std::bind(&MyWindow::writeDebug, &myWindow, _1, _2, _3)));
+      request.setOpt(Url(url));
+      
+      request.perform();
   }
 
 	catch ( curlpp::LogicError & e )
