@@ -73,8 +73,8 @@ int main(int argc, char *argv[])
 		curlpp::Easy request;
 
 		// Set the writer callback to enable cURL to write result in a memory area
-		curlpp::types::WriteFunctionFunctor functor(utilspp::BindFirst(utilspp::make_functor(&FileCallback), file));
-		curlpp::options::WriteFunction *test = new curlpp::options::WriteFunction(functor);
+		using namespace std::placeholders;
+		curlpp::options::WriteFunction *test = new curlpp::options::WriteFunction(std::bind(&FileCallback, file, _1, _2, _3));
 		request.setOpt(test);
 
 		// Setting the URL to retrive.
