@@ -21,7 +21,6 @@
  *    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  */
 
-#include "curlpp/internal/global.h"
 
 #include "curlpp/Options.hpp"
 #include "curlpp/Easy.hpp"
@@ -35,7 +34,3 @@ std::ostream & operator<<(std::ostream & stream, const curlpp::options::Url & ur
 
   return stream;
 }
-
-#if defined(CURLPP_TEMPLATE_EXPLICIT_INSTANTIATION)
-	#include "./Options.ins"
-#endif
